@@ -6,8 +6,9 @@ from pydantic import BaseModel, Field
 from sqlalchemy import create_engine
 from sqlalchemy.orm import sessionmaker, scoped_session
 
-from .event_memory import EventType, Base
+from .event_memory import Base
 from .event_memory_manager import EventMemoryManager
+from ..chat_history.messages import Roles
 from ..function_calling import LlamaCppFunctionTool
 from .core_memory_manager import CoreMemoryManager
 from .retrieval_memory_manager import RetrievalMemoryManager, RetrievalMemory
@@ -18,54 +19,6 @@ class CoreMemoryKey(Enum):
     HUMAN: str = "human"
 
 
-class core_memory_append(BaseModel):
-    """
-    Append a new entry to the Core Memory.
-    """
-
-    key: str = Field(..., description="The key identifier of the core memory.")
-    field: str = Field(..., description="The field within the core memory.")
-    value: str = Field(
-        ...,
-        description="The value or data to be stored in the specified core memory entry.",
-    )
-
-    def run(self, core_memory_manager: CoreMemoryManager):
-        return core_memory_manager.add_to_core_memory(
-            self.key, self.field, self.value
-        )
-
-
-class core_memory_replace(BaseModel):
-    """
-    Replace an entry in the Core Memory.
-    """
-
-    key: str = Field(..., description="The key identifier of the core memory.")
-    field: str = Field(..., description="The field within the core memory.")
-    new_value: str = Field(
-        ...,
-        description="The new value to replace with the existing data in the specified Core Memory field.",
-    )
-
-    def run(self, core_memory_manager: CoreMemoryManager):
-        return core_memory_manager.replace_in_core_memory(
-            self.key, self.field, self.new_value
-        )
-
-
-class core_memory_remove(BaseModel):
-    """
-    Remove an entry from the Core Memory.
-    """
-
-    key: str = Field(..., description="The key identifier of the core memory.")
-    field: str = Field(..., description="The field within the core memory.")
-
-    def run(self, core_memory_manager: CoreMemoryManager):
-        return core_memory_manager.remove_from_core_memory(self.key, self.field)
-
-
 class conversation_search(BaseModel):
     """
     Search prior conversation history using case-insensitive string matching.
@@ -87,10 +40,10 @@ class conversation_search(BaseModel):
             self.page = 0
         return event_memory_manager.query_events(
             event_types=[
-                EventType.UserMessage,
-                EventType.AgentMessage,
-                EventType.SystemMessage,
-                EventType.FunctionMessage,
+                Roles.user,
+                Roles.assistant,
+                Roles.system,
+                Roles.tool,
             ],
             content_keywords=self.keywords,
             start_date=parsed_start_datetime,
@@ -131,10 +84,10 @@ class conversation_search_date(BaseModel):
 
         return event_memory_manager.query_events(
             event_types=[
-                EventType.UserMessage,
-                EventType.AgentMessage,
-                EventType.SystemMessage,
-                EventType.FunctionMessage,
+                Roles.user,
+                Roles.assistant,
+                Roles.system,
+                Roles.tool,
             ],
             start_date=parsed_start_datetime,
             end_date=parsed_end_datetime,
@@ -182,10 +135,10 @@ class archival_memory_insert(BaseModel):
 
 class AgentRetrievalMemory:
     def __init__(
-        self,
-        persistent_db_path="./retrieval_memory",
-        embedding_model_name="all-MiniLM-L6-v2",
-        collection_name="retrieval_memory_collection",
+            self,
+            persistent_db_path="./retrieval_memory",
+            embedding_model_name="all-MiniLM-L6-v2",
+            collection_name="retrieval_memory_collection",
     ):
         self.retrieval_memory = RetrievalMemory(
             persistent_db_path, embedding_model_name, collection_name
@@ -210,10 +163,60 @@ class AgentRetrievalMemory:
         return self.add_retrieval_memory_tool
 
 
+def create_enum(enum_name, enum_values):
+    return Enum(enum_name, {value: value for value in enum_values})
+
+
 class AgentCoreMemory:
-    def __init__(self, core_memory=None, core_memory_file=None):
+    def __init__(self, core_memory_sections: list[str], core_memory=None, core_memory_file=None):
         if core_memory is None:
             core_memory = {}
+        custom_enum = create_enum("core_memory_sections", core_memory_sections)
+
+        class core_memory_append(BaseModel):
+            """
+            Append a new entry to the Core Memory.
+            """
+
+            key: custom_enum = Field(..., description="The key identifier of the core memory.")
+            field: str = Field(..., description="The field within the core memory.")
+            value: str = Field(
+                ...,
+                description="The value or data to be stored in the specified core memory entry.",
+            )
+
+            def run(self, core_memory_manager: CoreMemoryManager):
+                return core_memory_manager.add_to_core_memory(
+                    self.key.value, self.field, self.value
+                )
+
+        class core_memory_replace(BaseModel):
+            """
+            Replace an entry in the Core Memory.
+            """
+
+            key: custom_enum = Field(..., description="The key identifier of the core memory.")
+            field: str = Field(..., description="The field within the core memory.")
+            new_value: str = Field(
+                ...,
+                description="The new value to replace with the existing data in the specified Core Memory field.",
+            )
+
+            def run(self, core_memory_manager: CoreMemoryManager):
+                return core_memory_manager.replace_in_core_memory(
+                    self.key.value, self.field, self.new_value
+                )
+
+        class core_memory_remove(BaseModel):
+            """
+            Remove an entry from the Core Memory.
+            """
+
+            key: custom_enum = Field(..., description="The key identifier of the core memory.")
+            field: str = Field(..., description="The field within the core memory.")
+
+            def run(self, core_memory_manager: CoreMemoryManager):
+                return core_memory_manager.remove_from_core_memory(self.key.value, self.field)
 
         self.core_memory_manager = CoreMemoryManager(core_memory)
         if core_memory_file is not None:
@@ -229,6 +232,9 @@ class AgentCoreMemory:
             core_memory_replace, core_memory_manager=self.core_memory_manager
         )
 
+    def get_core_memory_view(self):
+        return self.core_memory_manager.build_core_memory_context()
+
     def get_core_memory_manager(self):
         return self.core_memory_manager
 
@@ -256,13 +262,13 @@ class AgentCoreMemory:
 
 
 class AgentEventMemory:
-    def __init__(self, event_queue_file=None, db_path="sqlite:///events.db"):
+    def __init__(self, event_queue_limit=30, event_queue_file=None, db_path="sqlite:///events.db"):
         self.engine = create_engine(db_path)
         session_factory = sessionmaker(bind=self.engine)
         Base.metadata.create_all(self.engine)
         self.Session = scoped_session(session_factory)
         self.session = self.Session()
-        self.event_memory_manager = EventMemoryManager(self.session)
+        self.event_memory_manager = EventMemoryManager(self.session, event_queue_limit=event_queue_limit)
 
         if event_queue_file is not None:
             self.event_memory_manager.load_event_queue(event_queue_file)
@@ -274,6 +280,8 @@ class AgentEventMemory:
             conversation_search_date, event_memory_manager=self.event_memory_manager
         )
 
+    def add_event(self, role: Roles, content:str):
+        self.event_memory_manager.add_event_to_queue(role, content, {})
     def get_event_memory_manager(self):
         return self.event_memory_manager
 
