@@ -177,14 +177,15 @@ class FunctionCallingAgent:
                 self.llama_cpp_tools, self.allow_parallel_function_calling
             )
         )
-
+        self.structured_output_settings.add_thoughts_and_reasoning_field = True
         self.without_grammar_mode = False
         self.without_grammar_mode_function = []
         self.prompt_suffix = ""
         if system_prompt is not None:
             self.system_prompt = system_prompt
         else:
-            self.system_prompt = """You are Funky, an AI assistant that calls functions to perform tasks."""
+            self.system_prompt = """You are Funky, an AI assistant that calls functions to perform tasks. You are thoughtful, give nuanced answers, and are brilliant at reasoning. Below is a list of functions you can use to interact with the system. Each function has specific parameters and requirements. Make sure to follow the instructions for each function carefully.
+Choose the appropriate function based on the task you want to perform. Provide your function calls in JSON format."""
         self.llama_cpp_agent = LlamaCppAgent(
             llama_llm,
             debug_output=debug_output,
@@ -226,6 +227,9 @@ class FunctionCallingAgent:
         structured_output_settings: LlmStructuredOutputSettings = None,
     ):
         self.llama_cpp_agent.add_message(role=Roles.user, message=message)
+        
+        if structured_output_settings is not None:
+            structured_output_settings.add_thoughts_and_reasoning_field = True
 
         result = self.intern_get_response(llm_sampling_settings=llm_sampling_settings, structured_output_settings=structured_output_settings)
 
