@@ -38,7 +38,7 @@ class VLLMServerSamplingSettings(LlmSamplingSettings):
     stream: bool = False
 
     def get_provider_identifier(self) -> LlmProviderId:
-        return LlmProviderId.tgi_server
+        return LlmProviderId.vllm_server
 
     def get_additional_stop_sequences(self) -> Union[List[str], None]:
         return None
@@ -73,12 +73,13 @@ class VLLMServerSamplingSettings(LlmSamplingSettings):
 
 
 class VLLMServerProvider(LlmProvider):
-    def __init__(self, base_url: str, model: str, api_key: str = None):
+    def __init__(self, base_url: str, model: str, huggingface_model: str, api_key: str = None):
         from openai import OpenAI
-
+        from transformers import AutoTokenizer
+        self.tokenizer = AutoTokenizer.from_pretrained(huggingface_model)
         self.client = OpenAI(
             base_url=base_url,
-            api_key=api_key,
+            api_key=api_key if api_key else "xxx-xxxxxxxx",
         )
         self.model = model
 
@@ -130,8 +131,9 @@ class VLLMServerProvider(LlmProvider):
 
             def generate_chunks():
                 for chunk in result:
-                    if chunk.choices[0].text is not None:
-                        yield {"choices": [{"text": chunk.choices[0].text}]}
+                    if chunk.choices is not None:
+                        if chunk.choices[0].text is not None:
+                            yield {"choices": [{"text": chunk.choices[0].text}]}
 
             return generate_chunks()
         else:
@@ -202,5 +204,5 @@ class VLLMServerProvider(LlmProvider):
             return {"choices": [{"text": result.choices[0].message.content}]}
 
     def tokenize(self, prompt: str) -> list[int]:
-        result = self.tokenize(prompt=prompt)
+        result = self.tokenizer.encode(text=prompt)
         return result
