@@ -1,4 +1,4 @@
 from .tool import WebSearchTool
 from .web_search_interfaces import WebCrawler, WebSearchProvider
 from .default_web_crawlers import TrafilaturaWebCrawler
-from .default_web_search_providers import DDGWebSearchProvider
+from .default_web_search_providers import DDGWebSearchProvider, GoogleWebSearchProvider
